.\" @(#)$RCSfile: lcg_cp_python.man,v $ $Revision: 1.6 $ $Date: 2009/07/09 14:11:41 $ CERN Remi Mollon
.\" Copyright (C) 2004-2006 by CERN
.\" All rights reserved
.\" 
.TH "LCG_CP" "3" "$Date: 2009/07/09 14:11:41 $" "LCG_UTIL" "Library Functions"

.SH "NAME"
lcg_cp - copy files from/to/between Storage Element(s),
without registering anything in the file catalog.

.SH "SYNOPSIS"
\fBimport lcg_util\fR
.sp
.BI "(int " returncode ,
.BI "string " errmsg
.BI ") lcg_cp3 (string " src_file ,
.BI "string " dest_file ,
.BI "string " defaulttype ,
.BI "string " srctype ,
.BI "string " dsttype ,
.BI "int " nobdii ,
.BI "string " vo ,
.BI "int " nbstreams ,
.BI "string " conf_file ,
.BI "int " insecure ,
.BI "int " verbose ,
.BI "int " timeout ,
.BI "string " src_spacetokendesc ,
.BI "string " dest_spacetokendesc );

.SH "DESCRIPTION"
.B lcg_cp
copies a Grid file to a local destination, or copie a local file to a SE (without
registering it in a file catalog).
.TP 
.I src_file
specifies the source file name: the protocol can be LFN, GUID, SURL, GSIFTP or local
file. An SURL scheme can be
.B sfn:
for a classical SE or
.BR srm: .
.TP 
.I dest_file
specifies the destination. The protocol can be SURL, GSIFTP or local file. An SURL
scheme can be
.B sfn:
for a classical SE or
.BR srm: .
SURL can be used only if
.I src_file
is GSIFTP or local file. In that case, the SURL will NOT be registered in a file
catalog.
.TP
.I defaulttype
specifies the default SE type you want to use. But if according to the BDII the default type
is not available for this SE, it will use another type.
Possible values are:
.RS
.TP 3.5i
.BR lcg_util.TYPE_NONE " or " "'none'"
No default type 
.TP
.BR lcg_util.TYPE_SE " or " "'se'"
Use classic SE endpoints 
.TP
.BR lcg_util.TYPE_SRM " or " "'srmv1'"
Use SRMv1 endpoints first
.TP
.BR lcg_util.TYPE_SRMv2 " or " "'srmv2'"
Use SRMv2 endpoints first
.RE
.TP
.I srctype
specifies the SE type you want to use for the source file. But if according to the BDII the default type
is not available for this SE, it will fail.
Possible values are:
.RS
.TP 3.5i
.BR lcg_util.TYPE_NONE " or " "'none'"
No default type 
.TP
.BR lcg_util.TYPE_SE " or " "'se'"
Use classic SE endpoints 
.TP
.BR lcg_util.TYPE_SRM " or " "'srmv1'"
Use SRMv1 endpoints first
.TP
.BR lcg_util.TYPE_SRMv2 " or " "'srmv2'"
Use SRMv2 endpoints first
.RE
.TP
.I dsttype
specifies the SE type you want to use for the destination file. But if according to the BDII the default type
is not available for this SE, it will fail.
Possible values are:
.RS
.TP 3.5i
.BR lcg_util.TYPE_NONE " or " "'none'"
No default type 
.TP
.BR lcg_util.TYPE_SE " or " "'se'"
Use classic SE endpoints 
.TP
.BR lcg_util.TYPE_SRM " or " "'srmv1'"
Use SRMv1 endpoints first
.TP
.BR lcg_util.TYPE_SRMv2 " or " "'srmv2'"
Use SRMv2 endpoints first
.RE
.TP
.I nobdii
If set to a non-zero value, it means that you don't want to make BDII calls to get SE type. So, you must provide the type of the SE
for srm: arguments, and full endpoint in SURLs. For SE type,
.I defaulttype
can be used (it will be used for both source and destination).
.TP 
.I nbstreams
specifies the number of parallel streams (default 1).
.TP 
.I timeout
specifies the timeout value (default 0).
.TP 
.I vo
specifies the Virtual Organization the user belongs to. If it is
not  specified,  the  environment  variable  LCG_GFAL_VO will be
used.
.TP 
.I conf_file
This argument is actually ignored.
.TP 
.I insecure
This argument is actually ignored.
.TP
.I src_spacetokendesc
specifies the space token to use with
.IR src_file .
Can be
.BR NULL .
.TP
.I dest_spacetokendesc
specifies the space token to use with
.IR dest_file .
Can be
.BR NULL .
.TP
.B verbose
Verbose level. Here are the possible levels:
.RS 
.TP 0.5i
.B 0
Only critical errors are put into errmsg.
.TP
.B 1
Warnings are displayed on stderr as well as critical errors.
.TP
.B 2
Debug information is displayed as well as warnings and critical errors.
.RE

.SH "NOTE"
The environment variable LCG_GFAL_INFOSYS must point to the BDII, unless
.I nobdii
is set to a non-zero value.
To use the RLS as catalog instead of the LFC, the environment variable
LCG_CATALOG_TYPE must explicitely be set to "edg". By default, it is set to "lfc".

.SH "RETURN VALUE"
This routine returns 0 if the operation was successful or \-1 if the operation
failed. In the latter case,
.B errno
is set appropriately.

.SH "ERRORS"
.TP 1.3i
.B ENOENT
The named file does not exist.
.TP 
.B EACCES
Permission denied.
.TP 
.B EFAULT
.IR src_file ,
.I dest_file
or
.I vo
is an invalid pointer.
.TP 
.B EINVAL
.I src_file
or
.I dest_file
has an invalid syntax.
.TP 
.B ECOMM
Communication error.
.TP
.B ENAMETOOLONG
.I vo
is too long. 
.TP
.B EPROTONOSUPPORT
Access method not supported.

.SH "SEE ALSO"
.BR lcg_aa_python (3),
.BR lcg_cp_python (3),
.BR lcg_cr_python (3),
.BR lcg_del_python (3),
.BR lcg_gt_python (3),
.BR lcg_la_python (3),
.BR lcg_lg_python (3),
.BR lcg_lr_python (3),
.BR lcg_ra_python (3),
.BR lcg_rep_python (3),
.BR lcg_rf_python (3),
.BR lcg_sd_python (3),
.BR lcg_stmd_python (3),
.BR lcg_uf_python (3)
