.\" @(#)$RCSfile: lcg_gt_python.man,v $ $Revision: 1.4 $ $Date: 2008/05/07 12:40:27 $ CERN Jean-Philippe Baud
.\" Copyright (C) 2005 by CERN
.\" All rights reserved
.\" 
.TH "LCG_GT" "3" "$Date: 2008/05/07 12:40:27 $" "LCG_UTIL" "Library Functions"

.SH "NAME"
lcg_gt \- get the TURL for a given SURL and transfer protocol

.SH "SYNOPSIS"
\fBimport lcg_util\fR
.sp
.BI "(int " returncode ,
.BI "string " turl ,
.BI "int " reqid ,
.BI "int " fileid ,
.BI "string " token ,
.BI "string " errmsg
.BI ") lcg_gt3 (string " surl ,
.BI "string " defaulttype ,
.BI "string " setype ,
.BI "int " nobdii ,
.BI "listOfString " protocols ,
.BI "int " timeout ,
.BI "string " spacetokendesc );

.SH "DESCRIPTION"
.B lcg_gt
gets the TURL for a given SURL and transfer protocol.
.TP 
.I surl
specifies the Site URL. An SURL scheme can be
.B sfn:
for a classical SE or
.BR srm: .
.TP 
.I protocol
specifies the protocol which will be used to access the file.
.TP 
.I protocols
specifies the list of protocols which can be used to access the file. This list must end by the empty string.
.TP 
.I turl
will be set by the routine to the address of the buffer which contains the TURL.
This buffer should be freed by the application after use.
.TP 
.I reqid
will receive the request identifier to be used to set the file state to
"Running" or "Done".
.TP 
.I fileid
will receive the file ordinal to be used to set the file state to
"Running" or "Done".
.TP 
.I token
will receive the request token to be used to set the file state to
"Running" or "Done".
.TP 
.I timeout
specifies the value of timeout(default 0)
.TP
.I defaulttype
specifies the default SE type you want to use. Possible values are
.BR TYPE_NONE ,
.BR TYPE_SE ,
.BR TYPE_SRM ,
.BR TYPE_SRMv2 ,
for respectively no default type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will use another type.
.TP
.I setype
specifies the SE type you want to use. Possible values are
.BR TYPE_NONE ,
.BR TYPE_SE ,
.BR TYPE_SRM ,
.BR TYPE_SRMv2 ,
for respectively no type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will fail.
.TP
.I nobdii
If set to a non-zero value, it means that you don't want to make BDII calls to get SE type. So, you must provide the type of the SE
for srm: arguments, and full endpoint in SURLs. For SE type,
.I defaulttype
can be used.
.TP
.I spacetokendesc
specifies the space token to use with
.IR surl .
Can be
.BR NULL .

.SH "NOTES"
The arguments (token, errbuf, errbufsz) are only meaningful if the space is managed by an SRM. The environment variable LCG_GFAL_INFOSYS must point to the BDII, unless
.I nobdii
is set to a non-zero value.

.SH "RETURN VALUE"
This routine returns 0 if the operation was successful or \-1 if the operation
failed. In the latter case,
.B errno
is set appropriately.

.SH "ERRORS"
.TP 1.3i
.B ENOENT
The named file does not exist.
.TP 
.B EACCES
Permission denied.
.TP 
.B EFAULT
One of the arguments is an invalid pointer.
.TP 
.B EINVAL
.I surl
has an invalid syntax.
.TP 
.B ECOMM
Communication error.
.TP
.B ENAMETOOLONG
The host name contained in
.I surl
is too long.
.TP
.B EPROTONOSUPPORT
Access method not supported.

.SH "FILES"
.B /opt/lcg/include/lcg_util.h
.TP 
.B /opt/lcg/lib/liblcg_util.so

.SH "SEE ALSO"
.BR lcg_aa_python (3),
.BR lcg_cp_python (3),
.BR lcg_cr_python (3),
.BR lcg_del_python (3),
.BR lcg_gt_python (3),
.BR lcg_la_python (3),
.BR lcg_lg_python (3),
.BR lcg_lr_python (3),
.BR lcg_ra_python (3),
.BR lcg_rep_python (3),
.BR lcg_rf_python (3),
.BR lcg_sd_python (3),
.BR lcg_stmd_python (3),
.BR lcg_uf_python (3)
