.\" @(#)$RCSfile: lcg_rf.man,v $ $Revision: 1.13 $ $Date: 2008/12/18 18:04:43 $ CERN Jean-Philippe Baud
.\" Copyright (C) 2005 by CERN
.\" All rights reserved
.\" 
.TH "LCG_RF" "3" "$Date: 2008/12/18 18:04:43 $" "LCG_UTIL" "Library Functions"

.SH "NAME"
lcg_rf \- register in the LRC (and optionally in the RMC) or the LFC a file residing on an SE

.SH "SYNOPSIS"
\fB#include "lcg_util.h"\fR
.sp
.BI "int lcg_rf (char *" surl ,
.BI "char *" guid ,
.BI "char *" lfn ,
.BI "char *" vo ,
.BI "char *" conf_file ,
.BI "int " insecure ,
.BI "int " verbose ,
.BI "char *" actual_gid );
.sp
.BI "int lcg_rft (char *" surl ,
.BI "char *" guid ,
.BI "char *" lfn ,
.BI "char *" vo ,
.BI "char *" conf_file ,
.BI "int " insecure ,
.BI "int " verbose ,
.BI "int " timeout,
.BI "char *" actual_gid );
.sp
.BI "int lcg_rfx (char *" surl ,
.BI "char *" guid ,
.BI "char *" lfn ,
.BI "char *" vo ,
.BI "char *" conf_file ,
.BI "int " insecure ,
.BI "int " verbose ,
.BI "char *" actual_gid ,
.BI "char *" errbuf ,
.BI "int " errbufsz );
.sp
.BI "int lcg_rfxt (char *" surl ,
.BI "char *" guid ,
.BI "char *" lfn ,
.BI "char *" vo ,
.BI "char *" conf_file ,
.BI "int " insecure ,
.BI "int " verbose ,
.BI "int " timeout,
.BI "char *" actual_gid ,
.BI "char *" errbuf ,
.BI "int " errbufsz );
.sp
.BI "int lcg_rf3 (char *" surl ,
.BI "char *" guid ,
.BI "char *" lfn ,
.BI "enum se_type" defaulttype ,
.BI "enum se_type" setype ,
.BI "int " nobdii ,
.BI "char *" vo ,
.BI "char *" conf_file ,
.BI "int " insecure ,
.BI "int " verbose ,
.BI "int " timeout,
.BI "char *" actual_gid ,
.BI "char *" errbuf ,
.BI "int " errbufsz );

.SH "DESCRIPTION"
.B lcg_rf
registers in the LRC (and optionally in the RMC) or the LFC a file residing on an SE.
.TP 
.I surl
specifies the site URL of the file to be registered. The scheme can be
.B sfn:
for a classical SE or
.BR srm: .
.TP 
.I guid
specifies the Grid Unique IDentifier. If NULL, a GUID is generated internally.
.TP 
.I lfn
specifies the Logical File Name associated with the file. If not NULL, an
entry is added to the Replica Metadata Catalog or the LFC.
.TP
.I defaulttype
specifies the default SE type you want to use. Possible values are
.BR TYPE_NONE ,
.BR TYPE_SE ,
.BR TYPE_SRM ,
.BR TYPE_SRMv2 ,
for respectively no default type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will use another type.
.TP
.I setype
specifies the SE type you want to use for the SURL. Possible values are
.BR TYPE_NONE ,
.BR TYPE_SE ,
.BR TYPE_SRM ,
.BR TYPE_SRMv2 ,
for respectively no type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will fail.
.TP
.I nobdii
If set to a non-zero value, it means that you don't want to make BDII calls to get SE type. So, you must provide the type of the SE
for srm: arguments, and full endpoint in SURLs. For SE type,
.I defaulttype
can be used (it will be used for both source and destination).
.TP 
.I vo
specifies the Virtual Organization the user belongs to. If it is not specified,
the environment variable LCG_GFAL_VO will be used.
.TP 
.I conf_file
This argument is currently ignored.
.TP 
.I insecure
This argument is currently ignored.
The access to the Replica Catalog or the LFC is done according to the endpoints published
in MDS.
.TP 
.I timeout
specifies the value of timeout (default 0).
.TP
.B verbose
Verbose level. Here are the possible levels:
.RS 
.TP 0.5i
.B 0
Only critical errors are displayed on stderr or put into errbuf if not null.
.TP
.B 1
Warnings are displayed on stderr as well as critical errors.
.TP
.B 2
Debug information is displayed as well as warnings and critical errors.
.RE
.TP 
.I actual_guid
specifies a buffer (minimum 37 bytes) to receive the actual guid.
This pointer can be NULL. In that case the actual guid is not returned.
.TP 
.I errbuf
specifies a buffer of size
.I errbufsz
to receive detailed error messages. If this pointer is NULL, the message goes
to stderr. The pointer should not be NULL if the application is a daemon or is
multi\-threaded.

.SH "NOTE"
The environment variable LCG_GFAL_INFOSYS must point to the BDII, unless
.I nobdii
is set to a non-zero value.
To use the RLS as catalog instead of the LFC, the environment variable
LCG_CATALOG_TYPE must explicitely be set to "edg". By default, it is set to "lfc".

.SH "RETURN VALUE"
This routine returns 0 if the operation was successful or \-1 if the
operation failed. In the latter case,
.B errno
is set appropriately.

.SH "ERRORS"
.TP 1.3i
.B ENOENT
The named file does not exist.
.TP 
.B EACCES
Permission denied.
.TP 
.B EFAULT
.I surl
or
.I vo
is an invalid pointer.
.TP 
.B EINVAL
.I surl
or
.I guid
is invalid.
.TP 
.B ECOMM
Communication error.
.TP
.B ENAMETOOLONG
.I lfn
or
.I vo
is too long. 
.TP
.B EPROTONOSUPPORT
Access method not supported.

.SH "FILES"
.B /opt/lcg/include/lcg_util.h
.TP 
.B /opt/lcg/lib/liblcg_util.so

.SH "SEE ALSO"
.BR lcg_aa (3),
.BR lcg_cp (3),
.BR lcg_cr (3),
.BR lcg_del (3),
.BR lcg_gt (3),
.BR lcg_la (3),
.BR lcg_lg (3),
.BR lcg_lr (3),
.BR lcg_ra (3),
.BR lcg_rep (3),
.BR lcg_rf (3),
.BR lcg_sd (3),
.BR lcg_stmd (3),
.BR lcg_uf (3)
