.\" @(#)$RCSfile: lcg_stmd.man,v $ $Revision: 1.2 $ $Date: 2008/05/07 12:40:28 $ CERN Remi Mollon
.\" Copyright (C) 2005 by CERN
.\" All rights reserved
.\"
.TH LCG_STMD 3 "$Date: 2008/05/07 12:40:28 $" LCG_UTIL "Library Functions"

.SH NAME
lcg_stmd \- get space tokens associated to a space token description, and their metadata

.SH SYNOPSIS
\fB#include "lcg_util.h"\fR
.sp
.BI "int lcg_stmd (char *" spacetokendesc ,
.BI "char *" endpoint ,
.BI "int *" nbtokens ,
.BI "gfal_spacemd **" spacemd ,
.BI "int " nobdii ,
.BI "int " timeout ,
.BI "char *" errbuf ,
.BI "int " errbufsz );

.SH DESCRIPTION
.B lcg_stmd
get space tokens associated to a space token description, and their metadata
.TP
.I spacetokendesc
the space token description whom you want to get metadata.
.TP
.I endpoint
the endpoint of the SE where the 
.I spacetokendesc
is defined. Note that as only SRMv2 supports space tokens the endpoint must be SRMv2-compliant.
.TP
.I nbtokens
a pointer to an integer, where will be stored the number of space tokens associated with
.IR spacetokendesc .
.TP
.I spacemd
a pointer to a table of 'gfal_spacemd' objects, where will be stored metadata of each space tokens
associated to 
.IR spacetokendesc .
Note that the memory will be allocated by the function itself, but it's up to the user to free it.
.TP
.I nobdii
If set to a non-zero value, it means that you don't want to make BDII calls to get SE type.
So, you must provide the full (SRMv2) endpoint.
.TP 
.I timeout
specifies the value of timeout (default 0).
.TP
.I errbuf
specifies a buffer of size 
.I errbufsz
to receive detailed error messages. If this pointer is NULL, the message goes
to stderr. The pointer should not be NULL if the application is a daemon or is
multi-threaded.

.SH NOTE
Only SRMv2 supports space tokens, so this function is compatible with SRMv2 endpoints only.
The environment variable LCG_GFAL_INFOSYS must point to the BDII, unless
.I nobdii
is set to a non-zero value.

.SH RETURN VALUE
This routine returns 0 if the operation was successful or -1 if the operation
failed. In the latter case,
.B errno
is set appropriately.

.SH ERRORS
.TP 1.3i
.B EINVAL
At least one of the arguments is not correct.
.TP
.B ENOMEM
Memory problem, maybe not enough free memory.
.TP
.B ECOMM
Communication error.

.SH FILES
.B /opt/lcg/include/lcg_util.h
.TP
.B /opt/lcg/lib/liblcg_util.so

.SH SEE ALSO
.BR lcg_aa (3),
.BR lcg_cp (3),
.BR lcg_cr (3),
.BR lcg_del (3),
.BR lcg_gt (3),
.BR lcg_la (3),
.BR lcg_lg (3),
.BR lcg_ra (3),
.BR lcg_rep (3),
.BR lcg_rf (3),
.BR lcg_sd (3),
.BR lcg_stmd (3),
.BR lcg_uf (3)
